Interactivity

Enum Interactivity 

pub enum Interactivity {
    Interactive,
    NonInteractive,
}
Primitive stream interactivity state.

Variants



Interactive

The stream appears to be attached to a terminal.



NonInteractive

The stream does not appear to be attached to a terminal.

Implementations

Source

impl Interactivity

pub const fn from_bool(is_terminal: bool) -> Self

Converts a boolean terminal result into an interactivity value.

pub const fn is_interactive(self) -> bool

Returns whether the stream is interactive.