pub enum Interactivity {
Interactive,
NonInteractive,
}Expand description
Primitive stream interactivity state.
Variants
Interactive
The stream appears to be attached to a terminal.
NonInteractive
The stream does not appear to be attached to a terminal.
Implementations
Sourceimpl Interactivity
impl Interactivity